@@ -6,12 +6,13 @@ import re
 import os
 from .export_template import doc_css, doc_html, slides_css
 from ..formatters import code_css
+from . import styles
 
 class _HhtmlExporter:
     # Should be used inside Slides class only.
     def __init__(self, _instance_BaseSlides):
         self.main = _instance_BaseSlides
-        self.main.widgets.toggles.export.observe(self._export, names = ['value']) # Export button
+        self.main.widgets.ddowns.export.observe(self._export, names = ['value']) # Export button
         
     def _htmlize(self, allow_non_html_repr = False, as_slides = False, **kwargs):
         "page_size, slide_number are in kwargs"
@@ -19,7 +20,9 @@ class _HhtmlExporter:
         for item in self.main:
             _html = ''
             for out in item.contents:
-                if 'text/html' in out.data:
+                if hasattr(out, 'fmt_html'): # columns and dynamic data
+                    _html += out.fmt_html(allow_non_html_repr = allow_non_html_repr)
+                elif 'text/html' in out.data:
                     _html += out.data['text/html']
                 elif allow_non_html_repr and (as_slides == False):
                     if 'text/plain' in out.data:
@@ -31,16 +34,15 @@ class _HhtmlExporter:
                         if kwargs.get("slide_number",False) and item.label != '0' else '')
                 content += (f'<section><div class="SlideArea">{_html}</div>{_sn}</section>' 
                             if as_slides else f'<section>{_html}</section>')
-                
-        theme_css = re.sub('\(.*-width.*\)','(max-width: 650px)',self.main.widgets.htmls.theme.value).replace('<style>','').replace('</style>','')
-        __style_css__ = (slides_css if as_slides else doc_css).replace('__theme_css__', theme_css) # They have style tag in them.
-        __code_css__ = self.main.widgets.htmls.hilite.value if as_slides else code_css(color='var(--primary-fg)')
         
-        return doc_html.replace(
-            '__page_size__',kwargs.get('page_size','letter')).replace(
-            '__code_css__', __code_css__).replace(
-            '__style_css__', __style_css__).replace(
-            '__content__', content)
+        theme_kws = {**self.main.settings.theme_kws,'breakpoint':'650px'}
+    
+        theme_css = styles.style_css(**theme_kws) # Theme CSS
+        _style_css = (slides_css if as_slides else doc_css).replace('__theme_css__', theme_css) # They have style tag in them.
+        _code_css = self.main.widgets.htmls.hilite.value if as_slides else code_css(color='var(--primary-fg)')
+        
+        return doc_html(_code_css,_style_css, content).replace(
+            '__page_size__',kwargs.get('page_size','letter'))
 
     def _writefile(self, path, content, overwrite = False):
         if os.path.isfile(path) and not overwrite:
@@ -50,7 +52,6 @@ class _HhtmlExporter:
         with open(path,'w') as f:
             f.write(content) 
             
-        print(f'File {path!r} saved!')
     
     def report(self, path='report.html', allow_non_html_repr = True, page_size = 'letter', overwrite = False):
         """Build a beutiful html report from the slides that you can print. Widgets are not supported for this purpose.
@@ -59,8 +60,6 @@ class _HhtmlExporter:
         - Use 'overrides.css' file in same folder to override CSS styles.
         - Use 'report-only' class to generate additional content that only appear in report.
         - Use 'slides-only' class to generate content that only appear in slides.
-        
-        New in 1.5.2
         """
         if self.main.citations and (self.main._citation_mode != 'global'):
             raise ValueError(f'''Citations in {self.main._citation_mode!r} mode are not supported in report. 
@@ -79,8 +78,6 @@ class _HhtmlExporter:
         - If a slide has only widgets or does not have single object with HTML representation, it will be skipped.
         - You can take screenshot (using system's tool) of a widget and add it back to slide using `Slides.image` to keep PNG view of a widget. 
         - To keep an empty slide, use at least an empty html tag inside an HTML like `IPython.display.HTML('<div></div>')`.
-        
-        New in 1.5.2
         """
         _path = os.path.splitext(path)[0] + '.html' if path != 'slides.html' else path
         content = self._htmlize(allow_non_html_repr = False, as_slides = True, slide_number = slide_number)
@@ -95,14 +92,14 @@ class _HhtmlExporter:
         def further_action(path):
             self.main.notify(f'File saved: {path!r}')
             os.startfile(path)
-            self.main.widgets.toggles.export.value = 2 # Reset so next click on same button will work
+            self.main.widgets.ddowns.export.value = 'Select' # Reset so next click on same button will work
         
-        if self.main.widgets.toggles.export.value == 1: # Report
+        if self.main.widgets.ddowns.export.value == 'Report': 
             path = os.path.join(_dir, 'report.html')
             self.report(path, allow_non_html_repr = False, overwrite = True)
             further_action(path)
             
-        elif self.main.widgets.toggles.export.value == 0: # Slides
+        elif self.main.widgets.ddowns.export.value == 'Slides': 
             path = os.path.join(_dir, 'slides.html')
             self.slides(path, overwrite = True)  
             further_action(path) 
\ No newline at end of file
