@@ -1,6 +1,7 @@
 # Template for building a report from slides 
 
-doc_html = '''<!DOCTYPE html>
+def doc_html(code_css, style_css, content):
+    return f'''<!DOCTYPE html>
 <html lang="en">
 <head>
     <meta charset="utf-8" />
@@ -10,8 +11,8 @@ doc_html = '''<!DOCTYPE html>
     <script src="https://cdnjs.cloudflare.com/ajax/libs/require.js/2.1.10/require.min.js"></script>
     <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/2.0.3/jquery.min.js"></script> 
     
-    __code_css__
-    __style_css__
+    {code_css}
+    {style_css}
 
     <!-- Custom stylesheet, it must be in the same directory as the html file -->
     <link rel="stylesheet" href="overrides.css">
@@ -21,21 +22,21 @@ doc_html = '''<!DOCTYPE html>
     <script src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/latest.js?config=TeX-AMS_HTML"></script>
     <!-- MathJax configuration -->
     <script type="text/x-mathjax-config">
-    MathJax.Hub.Config({
-        tex2jax: {
+    MathJax.Hub.Config({{
+        tex2jax: {{
             inlineMath: [ ["$","$"] ],
             displayMath: [ ["$$","$$"] ],
             processEscapes: true,
             processEnvironments: true
-        },
-        // Center justify equations in code and markdown cells. Elsewhere
+        }},
+        // align-center justify equations in code and markdown cells. Elsewhere
         // we use CSS to left justify single line equations in code cells.
         displayAlign: "center",
-        "HTML-CSS": {
-            styles: {".MathJax_Display": {"margin": 0}},
-            linebreaks: { automatic: true }
-        }
-    });
+        "HTML-CSS": {{
+            styles: {{".MathJax_Display": {{"margin": 0}}}},
+            linebreaks: {{ automatic: true }}
+        }}
+    }});
     </script>
     <!-- End of mathjax configuration -->
 </head>
@@ -43,7 +44,7 @@ doc_html = '''<!DOCTYPE html>
 <div>
     <!-- Classes below work for both scenerios -->
     <div class="SlidesWrapper">
-    __content__
+    {content}
     </div>
 </div>
 </body>
@@ -66,7 +67,7 @@ body div.highlight, body div.highlight pre {
     width: 100% !important;
     }
     
-figure, img, .zoom-container, table, .block {margin: 0 auto !important;} /* center images */
+figure, img, .zoom-child, table, .block {margin: 0 auto !important;} /* center images */
 div.columns { /* ovveride slides css */
     width:100%;
     max-width:100%;
@@ -83,7 +84,7 @@ div.columns > div[style*="width:"] {
 .SlidesWrapper h1, .SlidesWrapper h2,
 .SlidesWrapper h3, .SlidesWrapper h4,
 .SlidesWrapper h5, .SlidesWrapper h6 {
-	color:var(--heading-fg);
+	color:var(--heading-color);
  	text-align: left !important;
 	overflow:hidden; /* FireFox */
     margin-block: 0.6em 0.5em !important;
@@ -107,13 +108,13 @@ div.columns > div[style*="width:"] {
 }
 @media print {
     :root {
-	    --heading-fg: navy;
+	    --heading-color: navy;
 	    --primary-fg: black;
 	    --primary-bg: white;
 	    --secondary-bg: whitesmoke;
 	    --secondary-fg: #454545;
-	    --tr-odd-bg: whitesmoke;
-	    --tr-hover-bg: #D1D9E1;
+	    --alternate-bg: whitesmoke;
+	    --hover-bg: #D1D9E1;
 	    --accent-color: navy;
     }
     * {
@@ -131,11 +132,11 @@ div.columns > div[style*="width:"] {
         padding-bottom: 18mm;
         height: auto;
     }
-    code, span, figure, img, svg, .zoom-container, blockquote { 
+    code, span, figure, img, svg, .zoom-child, .zoom-self, blockquote { 
         page-break-inside: avoid !important; 
     }
     ::-webkit-scrollbar { height: 0 !important; width: 0 !important; }
-    div.highlight, pre, .RawText {
+    div.highlight, pre, .raw-text {
         height:auto;
         max-height: auto !important; 
         overflow-wrap: break-word !important; 
@@ -147,14 +148,14 @@ div.columns > div[style*="width:"] {
     h1,h2,h3,h4 { page-break-before : auto !important; page-break-after : avoid !important; page-break-inside : avoid !important; }
     
     /* Blocks should be handled properly in white scenerio*/
-    .Note {background: rgba(250,250,250,0.75);}
-    .Block-red {background: rgba(250,230,230,0.75);}
-    .Block-green {background: rgba(230,250,230,0.75);}
-    .Block-blue {background: rgba(230,230,250,0.75);}
-    .Block-yellow {background: rgba(250,250,230,0.75);}
-    .Block-cyan {background: rgba(230,250,250,0.75);}
-    .Block-gray {background: rgba(230,230,230,0.75);}
-    .Block-magenta {background: rgba(250,230,250,0.75);}
+    .note {background: rgba(250,250,250,0.75);}
+    .block-red {background: rgba(250,230,230,0.75);}
+    .block-green {background: rgba(230,250,230,0.75);}
+    .block-blue {background: rgba(230,230,250,0.75);}
+    .block-yellow {background: rgba(250,250,230,0.75);}
+    .block-cyan {background: rgba(230,250,250,0.75);}
+    .block-gray {background: rgba(230,230,230,0.75);}
+    .block-magenta {background: rgba(250,230,250,0.75);}
 }
 </style>
 '''
