@@ -14,7 +14,6 @@ class Navigation:
         self.btn_settings = self.widgets.buttons.setting
         self.visible_slider = self.widgets.sliders.visible
     
-        
         self.btn_prev.on_click(self._shift_left)
         self.btn_next.on_click(self._shift_right)
         self.btn_settings.on_click(self._toggle_panel)
@@ -41,7 +40,7 @@ class Navigation:
                 self.progress_slider.index = self.progress_slider.index - 1 # Backwards
     
     def _change_icons(self, change):
-        
+        self.widgets.mainbox.remove_class('InView-Other') # A heart beat animation should stop, and will be re-registed by content update
         if '.' in self.progress_slider.options[self.progress_slider.index - 1][0]:
             self.btn_prev.icon = 'chevron-up'
         else:
@@ -54,13 +53,13 @@ class Navigation:
             self.btn_next.icon = 'chevron-right'
     
     def _toggle_panel(self,change):
-        if self.btn_settings.description == '\u2699':
-            self.btn_settings.description  = '✕'
+        if self.btn_settings.icon == 'plus':
+            self.btn_settings.icon  = 'minus'
             self.widgets.panelbox.layout.display = 'flex'
             self.btn_next.disabled = True
             self.btn_prev.disabled = True
         else:
-            self.btn_settings.description = '\u2699'
+            self.btn_settings.icon = 'plus' #'ellipsis-v'
             self.widgets.panelbox.layout.display = 'none'
             self.btn_next.disabled = False
             self.btn_prev.disabled = False
