@@ -10,25 +10,18 @@ class Notes:
         # print(f'Inside: {self.__class__.__name__}')
         self.main = _insatanceSlides
         self.widgets = _instanceWidgets
-        
         self.notes_check = self.widgets.checks.notes
-        self.btn_timer = self.widgets.toggles.timer
-        
-        self.start_time = None
-        
         self.notes_check.observe(self.__open_close_notes, names=['value'])
-        self.btn_timer.observe(self.__timeit,names=['value'])
         
     def insert(self, content):
         """Add notes to current slide. Content could be any object except javascript and interactive widgets.
-        
-        **New in 1.7.2**      
-        In markdown, you can use alert`notes\`notes content\``."""
-        if not self.main._running_slide:
+        ::: note-tip     
+            In markdown, you can use alert`notes\`notes content\``."""
+        if self.main.running is None:
             raise RuntimeError('Notes can only be added inside a slide constructor.')
         
         with suppress(BaseException): # Would work on next run, may not first time
-            self.main._running_slide._notes = self.main.format_html(content)._repr_html_()
+            self.main.running._notes = self.main.format_html(content)._repr_html_()
     
     def _display(self, html_str):
         self.widgets.htmls.notes.value = 'Notes Area: Time only updates while switching slides' # Must be, so when no notes, should not be there
@@ -38,27 +31,17 @@ class Notes:
                 time_str = f'{current_time.tm_hour-12:0>2}:{current_time.tm_min:0>2} PM'
             else:
                 time_str = f'{current_time.tm_hour:0>2}:{current_time.tm_min:0>2} AM'
-            
-            
-            if self.start_time:
-                spent = time.time() - self.start_time 
-                h, sec = divmod(spent,3600) # Houres
-                m, _ = divmod(sec,60) # Minutes
-                spent_str = f'{int(h):0>2}:{int(m):0>2}' # They are floats by default
-            else:
-                spent_str = '00:00'
 
             _time = f'''<div style="border-radius:4px;padding:8px;background:var(--secondary-bg);min-width:max-content;">
-                        <h2>Time: {time_str}</h2><hr/>
-                        <h3>Elapsed Time: {spent_str}</h3><div>'''
+                        <h2>Time: {time_str}</h2><div>'''
                         
             self.widgets.htmls.notes.value = f'''<div style="margin:-4px;padding:4px;background:var(--secondary-bg);border-radius:4px 4px 0 0;">
-                    <b style="font-size:110%;color:var(--accent-color);">Time: {time_str} | Elapsed Time: {spent_str}</b>
+                    <b style="font-size:105%;color:var(--accent-color);">Time: {time_str}</b>
                     </div>''' + html_str # show alaways
             
             # Next everything for Browser window case
             if self.notes_check.value:  # Only show on demand
-                theme = self.widgets.htmls.theme.value.replace('FullScreen','') #important
+                theme = self.widgets.htmls.theme.value.replace('FullWindow','') #important
                 code_theme = '''<style> 
                                 pre { display:flex; flex-direction:column; } 
                                 .SlideBox { display:flex; flex-direction:row; justify-content:space-between;}
@@ -88,11 +71,3 @@ class Notes:
                 ''')
         else:
             self.widgets._exec_js('window.open("","__Notes_Window__","popup").close();')
-    
-    def __timeit(self,change):
-        if change['new'] == True:
-            self.btn_timer.icon = 'pause'
-            self.start_time = time.time() # Start time here
-        else:
-            self.btn_timer.icon = 'play'
-            self.start_time = None
