@@ -51,7 +51,6 @@ class ScreenShot:
                         self.widgets.sliders.visible,
                         self.widgets.htmls.toast,
                         self.widgets.htmls.cursor,
-                        self.widgets.toggles.display,
                         *additional_widgets_to_hide
                         ]
         old_pref = self.widgets.htmls.toast.layout.visibility # To keep user prefernce back after screenshot
@@ -177,15 +176,24 @@ class ScreenShot:
     
     def __clear_images(self,change):
         if 'Current' in self.widgets.ddowns.clear.value:
-            _ = [img.close() for img in self.__images[self.widgets.sliders.progress.label]] # Close image to save mememory          
+            _how_many = [img.close() for img in self.__images.get(self.widgets.sliders.progress.label,[])] # Close image to save mememory          
             self.__images[self.widgets.sliders.progress.label] = [] # Clear images at that slide       
-            self.widgets._push_toast('Deleted screenshots of current slide')
+            
+            if _how_many:
+                self.widgets._push_toast(f'Deleting screenshots of current slide. {len(_how_many)} images deleted.')
+            else:
+                self.widgets._push_toast('No screenshots found for to delete.',timeout=2)
             
         elif 'All' in self.widgets.ddowns.clear.value:
-            for imgs in self.__images.values():
-                _ = [img.close() for img in imgs] # Close image to save mememory
+            flat_imgs = [img for imgs in self.__images.values() for img in imgs]
+            _how_many = [img.close() for img in flat_imgs] # Close image to save mememory
+            if _how_many:
+                self.widgets._push_toast(f'Deleting screenshots of all slides. {len(_how_many)} images deleted.')
+            else:
+                self.widgets._push_toast('No screenshots found for to delete.', timeout=2)
+            
             self.__images = {} # Cleaned up
-            self.widgets._push_toast('Deleted screenshots of all slides')
+            
         
         self.widgets.ddowns.clear.value = 'None' # important to get back after operation
     
@@ -193,7 +201,7 @@ class ScreenShot:
     def clipboard_image(self, filename, quality = 95, **kwargs):
         """Save image from clipboard to file and return alert`ipyslides.utils.image`. 
         On next run, it loads from saved file under `notebook-dir/ipyslides-assets/screenshots`. Useful to add screenshots from system into IPython.
-        kwargs are passed to `ipyslides.utils.image`. Added in 2.0.1"""
+        kwargs are passed to `ipyslides.utils.image`."""
         directory = os.path.join(self.widgets.assets_dir,'screenshots')
         
         if not os.path.isdir(directory):
@@ -209,6 +217,4 @@ class ScreenShot:
                 im.save(filepath, format= im.format,quality = quality) # Save image to file for later use
                 return image(filepath, **kwargs)
             else:
-                return print('No image on clipboard/file or not supported format.')
-        
-    
\ No newline at end of file
+                return print('No image on clipboard/file or not supported format.')  
\ No newline at end of file
