@@ -4,8 +4,10 @@ resize_js = "window.dispatchEvent(new Event('resize'));"
 multi_slides_alert = """
 let slides = document.getElementsByClassName('SlidesWrapper');
 if (slides.length > 1) {
-    alert('''You have slides open in other notebook(s) in currnet tab. 
-    Please close their view by using `.close_view()` method and re-run here to have smooth navigations via keyboard!''');
+    alert(`You may have slides open in other notebook(s) in currnet tab. In that case use .close_view() method on them 
+and re-run to have smooth navigations via keyboard!
+
+If this is not the case, then there could be left over disconnect slides from previous session. Then restart kernel with clear all outputs option.`);
 };
 """
 
@@ -16,14 +18,14 @@ function main(){
     }; 
     resizeWindow(); // resize on first display
     // Only get buttons of first view, otherwise it will becomes multiclicks
-    let arrows  = document.getElementsByClassName('arrows'); // These are 2*instances
-    let mplBtn  = document.getElementsByClassName('mpl-zoom')[0];
-    let winFs   = document.getElementsByClassName('window-fs')[0];
-    let capSc   = document.getElementsByClassName('screenshot-btn')[0];
-    let cursor  = document.getElementsByClassName('LaserPointer')[0];
-    let present = document.getElementsByClassName('presenter-btn')[0];
-    let panelBtn = document.getElementsByClassName('SidePanel-Btn')[0];
-
+    let arrows   = document.getElementsByClassName('Arrows'); // These are 2*instances
+    let mplBtn   = document.getElementsByClassName('Zoom-Btn')[0];
+    let winFs    = document.getElementsByClassName('FullWindow-Btn')[0];
+    let fullSc   = document.getElementsByClassName('FullScreen-Btn')[0];
+    let capSc    = document.getElementsByClassName('Screenshot-Btn')[0];
+    let cursor   = document.getElementsByClassName('LaserPointer')[0];
+    let panelBtn = document.getElementsByClassName('Settings-Btn')[0];
+    let laserBtn = document.getElementsByClassName('Laser-Btn')[0];
     
     // Keyboard events
     function keyOnSlides(e) {
@@ -38,6 +40,8 @@ function main(){
             mplBtn.click(); // Z 
         } else if (key === 71) { 
             panelBtn.click(); // G
+        } else if (key === 76) {
+            laserBtn.click(); // L
         } else if (key === 88 || key === 68) {
             alert("Pressing X or D,D may cut selected cell! Click outside slides to capture these keys!");
             e.stopPropagation(); // stop propagation to jupyterlab events
@@ -49,10 +53,7 @@ function main(){
             winFs.click(); // Toggle Window with W 
         } else if (key === 70) { 
             // F to enter fullscreen
-            document.getElementsByClassName('SlidesWrapper')[0].requestFullscreen();
-            if (!winFs.classList.contains('mod-active')) {
-                winFs.click(); // Make layout fullscreen as well
-            };
+            fullSc.click(); // Toggle Fullscreen with F
         } else if (key === 27) {  
             // Escape to exit fullscreen
             document.getElementsByClassName('SlidesWrapper')[0].exitFullscreen();
@@ -62,11 +63,10 @@ function main(){
             capSc.click();  // S for screenshot
         } else if (key === 80) {
             window.print(); // P for PDF print
-        } else if (key === 84) { 
-            present.click(); // T for presenter and timer start
         }; 
         resizeWindow(); // Resize after key press, good for F key
         e.stopPropagation(); // stop propagation to jupyterlab events and other views 
+        e.preventDefault(); // stop default actions
     };
     
     let box = document.getElementsByClassName('SlidesWrapper')[0];
@@ -94,13 +94,6 @@ function main(){
     if (loc.includes("voila")) {
         winFs.click(); // Turn ON fullscreen for voila anywhare.
     };
-    // Do this at end so that at least other things work in Voila
-    try {
-        let main = document.getElementById('jp-main-dock-panel'); //Need for resizing events on LabShell
-        main.onmouseup = resizeWindow; // So that Voila works
-    } catch (error) { 
-    
-    }
     
 };
 
@@ -108,7 +101,7 @@ function main(){
 function beta_swiper(){
     let box = document.getElementsByClassName('SlidesWrapper')[0];
     box.tabIndex = -1;
-    let arrows = document.getElementsByClassName('arrows'); // These are 2*instances
+    let arrows = document.getElementsByClassName('Arrows'); // These are 2*instances
 
     let startX = 0;
     let endX = 0;
@@ -130,7 +123,7 @@ function beta_swiper(){
         if (Math.abs(endY - startY) < 20) {
             // Y axis is not important but we should avoid X component of touch for a long y-scroll
             if ((endX - startX) < -40 && startX > (bbox.right - 50)) {
-                arrows[1].click(); // Left Swipe to Next
+                arrows[1].click(); // align-left Swipe to Next
             };
 
             if ((endX - startX) > 40 && startX < (bbox.left + 50)) {
