@@ -8,8 +8,10 @@ import ipywidgets as ipw
 from IPython.display import display, Javascript
 from ipywidgets import HTML, FloatProgress, VBox, HBox, Box, GridBox, Layout, Button
 from . import styles, _layout_css
-from ..utils import html
+from ..utils import html, _build_css
 
+def _build_style_widget(css_dict):
+    return HTML(html('style',_build_css((), css_dict)).value)
 
 auto_layout =  Layout(width='auto')
 def describe(value): 
@@ -19,15 +21,16 @@ class _Buttons:
     """
     Instantiate under `Widgets` class only.
     """
-    prev    =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto')).add_class('arrows')
-    next    =  Button(icon='chevron-right',layout= Layout(width='auto',height='auto')).add_class('arrows')
-    setting =  Button(description= '\u2699',layout= Layout(width='auto',height='auto', tooltip='Toggle Settings')).add_class('menu').add_class('SidePanel-Btn')
-    toc     =  Button(description= '\u2630',layout= Layout(width='auto',height='auto', tooltip='Toggle Table of Contents')).add_class('menu').add_class('Toc-Btn')
-    home    =  Button(description= 'Home',layout= Layout(width='auto',height='auto', tooltip='Go to Title Page')).add_class('menu')
-    end     =  Button(description= 'End',layout= Layout(width='auto',height='auto', tooltip='Go To End of Slides')).add_class('menu')
+    prev    =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto'),tooltip='Previous Slide [<, Shift + Space]').add_class('Arrows').add_class('Prev-Btn')
+    next    =  Button(icon='chevron-right',layout= Layout(width='auto',height='auto'),tooltip='Next Slide [>, Space]').add_class('Arrows').add_class('Next-Btn')
+    setting =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Toggle Settings [G]').add_class('Menu-Item').add_class('Settings-Btn')
+    toc     =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Toggle Table of Contents').add_class('Menu-Item').add_class('Toc-Btn')
+    refresh =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'),tooltip='Refresh dynmaic content across all slides').add_class('Menu-Item').add_class('Refresh-Btn')
+    home    =  Button(description= 'Home',layout= Layout(width='auto',height='auto', tooltip='Go to Title Page')).add_class('Menu-Item')
+    end     =  Button(description= 'End',layout= Layout(width='auto',height='auto', tooltip='Go To End of Slides')).add_class('Menu-Item')
     capture =  Button(icon='camera',layout= Layout(width='auto',height='auto'),
-                tooltip='Take Screen short in full screen. Order of multiple shots in a slide is preserved!',
-                ).add_class('screenshot-btn') # .add_class('menu')
+                tooltip='Take Screen short in full screen. Order of multiple shots in a slide is preserved! [S]',
+                ).add_class('Screenshot-Btn').add_class('Menu-Item')
     pdf     = Button(description='Save PDF',layout= Layout(width='auto',height='auto'))
     png     = Button(description='Save PNG',layout= Layout(width='auto',height='auto'))
     cap_all = Button(description='Capture All',layout= Layout(width='auto',height='auto'))
@@ -37,11 +40,11 @@ class _Toggles:
     """
     Instantiate under `Widgets` class only.
     """
-    export  = ipw.ToggleButtons(description='Export As: ',options=[('Slides',0),('Report',1),('None',2)], value = 2).add_class('export-btn').add_class('menu')
-    display = ipw.ToggleButton(description='◨', value = False, tooltip='Toggle ON/OFF Sidebar Mode').add_class('DisplaySwitch').add_class('voila-sidecar-hidden').add_class('menu')
-    fscrn   = ipw.ToggleButton(description='Window',icon='expand',value = False).add_class('sidecar-only').add_class('window-fs')
-    zoom    = ipw.ToggleButton(description='Zoom Items',icon='toggle-off',value = False).add_class('sidecar-only').add_class('mpl-zoom')
-    timer   = ipw.ToggleButton(description='Timer',icon='play',value = False).add_class('sidecar-only').add_class('presenter-btn')             
+    window  = ipw.ToggleButton(icon='plus',value = False, tooltip='Fit/Restore Viewport [W]').add_class('FullWindow-Btn').add_class('Menu-Item')
+    fscreen = ipw.ToggleButton(icon='plus',value = False, tooltip='Toggle Fullscreen [F]').add_class('FullScreen-Btn').add_class('Menu-Item')
+    zoom    = ipw.ToggleButton(icon='plus',value = False, tooltip='Toggle Zooming Items [Z]').add_class('Zoom-Btn')
+    laser   = ipw.ToggleButton(icon='plus',value = False, tooltip='Toggle Laser Pointer [L]').add_class('Laser-Btn') 
+    overlay = ipw.ToggleButton(icon='plus',value = False, tooltip='Toggle Overlay Panel').add_class('Overlay-Btn')          
         
 
 @dataclass(frozen=True)
@@ -50,34 +53,29 @@ class _Htmls:
     Instantiate under `Widgets` class only.
     """
     footer  = HTML('<p>Put Your Info Here using `self.set_footer` function</p>',layout=Layout(margin='0')).add_class('Footer') # Zero margin is important
-    theme   = HTML(html('style',styles.style_css(styles.theme_roots['Fancy'].replace(
-                '__text_size__','20px')).replace(
-                '__breakpoint_width__','650px').replace(
-                '__textfont__','STIX Two Text').replace(
-                '__codefont__','var(--jp-code-font-family)')
-                ).value)
-    main    = HTML(html('style',_layout_css.layout_css.replace('__breakpoint_width__','650px')).value) # Will be update in theme as well
-    sidebar = HTML(html('style',_layout_css.sidebar_layout_css()).value) # Should be separate CSS
-    loading = HTML() #SVG Animation in it
+    theme   = HTML(html('style',styles.style_css(styles.theme_colors['Inherit'])).value)
+    main    = HTML(html('style',_layout_css.layout_css('650px', styles.theme_colors['Inherit']['accent_color'])).value) # Will be update in theme as well
+    window  = HTML(html('style','').value) # Should be separate CSS, need class to handle disconnect options
+    loading = HTML(layout=Layout(display='none')).add_class('Loading') #SVG Animation in it
     logo    = HTML()
     tochead = HTML('<h4>Table of Contents</h4><hr/>')
     toast   = HTML().add_class('Toast') # For notifications
     cursor  = HTML().add_class('LaserPointer') # For beautiful cursor
     notes   = HTML('Notes Area').add_class('Inline-Notes') # For below slides area
     hilite  = HTML() # Updated in settings on creation. For code blocks.
-    fscrn   = HTML() # Full Screen CSS, do not add here!
-    zoom    = HTML() # zoom-container CSS, do not add here!
-    capture = HTML('<span class="Info">Edit above box and hit Enter to see screenshot here. ' 
-                   'If nothing shown, your system does not support taking screenshots with PIL</span>').add_class('capture-html') # Screenshot image here
-    intro   = HTML().add_class('panel-text') # Intro HTML
-    glass = HTML().add_class('BackLayer') # For glass effect
+    zoom    = HTML() # zoom CSS, do not add here!
+    capture = HTML('<span class="info">Edit above box and hit Enter to see screenshot here. ' 
+                   'If nothing shown, your system does not support taking screenshots with PIL</span>').add_class('CaptureHtml') # Screenshot image here
+    intro   = HTML().add_class('SidePanel-Text') # Intro HTML
+    glass   = HTML().add_class('BackLayer') # For glass effect
+    overlay = HTML().add_class('OverlayHtml') # For adding iframe of things
 
 @dataclass(frozen=True)
 class _Inputs:
     """
     Instantiate under `Widgets` class only.
     """
-    bbox = ipw.Text(description='L,T,R,B (px)',layout=auto_layout,value='Type left,top,right,bottom pixel values and press ↲').add_class('bbox-input')
+    bbox = ipw.Text(description='L,T,R,B (px)',layout=auto_layout,value='Type left,top,right,bottom pixel values and press ↲').add_class('Bbox-Input')
 
 @dataclass(frozen=True)
 class _Checks:
@@ -94,20 +92,19 @@ class _Sliders:
     Instantiate under `Widgets` class only.
     """
     progress = ipw.SelectionSlider(options=[('0',0)], value=0, continuous_update=False,readout=True)
-    visible  = ipw.IntSlider(description='View (%)',min=0,value=100,max=100,orientation='vertical').add_class('float-control')
-    height   = ipw.IntSlider(**describe('Height (px)'),min=200,max=2160, value = 400,continuous_update=False).add_class('height-slider') #2160 for 4K screens
-    width    = ipw.IntSlider(**describe('Width (vw)'),min=20,max=100, value = 40,continuous_update=False).add_class('width-slider') # 40 is best if something goes wrong, it can be pushed back
+    visible  = ipw.IntSlider(description='View (%)',min=0,value=100,max=100,orientation='vertical').add_class('FloatControl')
+    width    = ipw.IntSlider(**describe('Width (vw)'),min=20,max=100, value = 70,continuous_update=False).add_class('Width-Slider') 
     scale    = ipw.FloatSlider(**describe('Font Scale'),min=0.5,max=3,step=0.0625, value = 1.0,readout_format='5.3f',continuous_update=False)
         
-
 @dataclass(frozen=True)
 class _Dropdowns:
     """
     Instantiate under `Widgets` class only.
     """
-    theme = ipw.Dropdown(**describe('Theme'),options=[*styles.theme_roots.keys(),'Custom'],value='Inherit')
-    clear = ipw.Dropdown(**describe('Delete'),options = ['None','Delete Current Slide Screenshots','Delete All Screenshots'])
-        
+    aspect = ipw.Dropdown(**describe('Aspect Ratio'),options=[('2:1',0.50),('16:9',0.56),('16:10',0.63),('3:2',0.67), ('7:5',0.71),('4:3',0.75),('5:4',0.80)], value = 0.56,continuous_update=False).add_class('Height-Dd') #16:9 is better for in cell display
+    theme  = ipw.Dropdown(**describe('Theme'),options=[*styles.theme_colors.keys(),'Custom'],value='Inherit')
+    clear  = ipw.Dropdown(**describe('Delete'),options = ['None','Delete Current Slide Screenshots','Delete All Screenshots'])
+    export = ipw.Dropdown(**describe('Export As'),options=['Slides','Report','Select'], value = 'Select')
     
 @dataclass(frozen=True)
 class _Outputs:
@@ -123,70 +120,71 @@ class _Outputs:
 def _custom_progressbar(intslider):
     "Retruns a progress bar with custom style html linked to the slider"
     # This html should not be exposed to user
-    html = HTML('''
-    <style>
-    .NavWrapper .nav-box .menu {
-        font-size:24px !important; 
-        overflow:hidden;
-        opacity:0.4;
-        z-index:55;
-    }
-    .NavWrapper .nav-box .menu:hover {
-        opacity:1;
-    }
-    .NavWrapper .nav-box .Footer p {
-        font-size:14px !important;
-    }
-    .NavWrapper .nav-box {
-        z-index:50;
-        overflow: hidden;
-    }
-    .NavWrapper .widget-hprogress {
-        height:4px; !impportant;
-    }
-    .NavWrapper, .NavWrapper > div {
-        padding:0px;
-        margin:0px;
-        overflow:hidden;
-        max-width:100%;
-    }
-    .NavWrapper .progress, .NavWrapper .progress .progress-bar {
-        border-radius:0px; 
-        margin:0px;
-        padding:0px;
-        height:4px !important;
-        overflow:hidden;
-        left:0px;
-        bottom:0px;
-    }
-    .NavWrapper .progress {
-        width:100% !important;
-        transform:translate(-2px,1px) !important;
-    }
-    </style>''')
+    html = _build_style_widget({
+        '.NavWrapper': {
+            '^,^ > div': {
+                'padding': '0px',
+                'margin': '0px',
+                'overflow': 'hidden',
+                'max-width': '100%',
+            },
+            '.progress': {
+                'width': '100% !important',
+                'transform': 'translate(-2px,1px) !important',
+                '^, .progress-bar': {
+                    'border-radius': '0px',
+                    'margin': '0px',
+                    'padding': '0px',
+                    'height': '4px !important',
+                    'overflow': 'hidden',
+                    'left': '0px',
+                    'bottom': '0px',
+                },
+            },
+            '.widget-hprogress': {
+                'height': '4px !important',
+            },
+            '.NavBox': {
+                'z-index': '2',
+                'overflow': 'hidden',
+                '.Menu-Item': {
+                    'font-size': '18px !important',
+                    'overflow': 'hidden',
+                    'opacity': '0.4',
+                    'z-index': '3',
+                    '^:hover': {
+                        'opacity': '1',
+                    },
+                },
+                '.Footer p': {
+                    'font-size': '14px !important',
+                },
+            },
+        },
+    }) # Should be HTML Widget
     intprogress = FloatProgress(min=0, max=100,value=0, layout=Layout(width='100%'))
     ipw.link((intslider, 'value'), (intprogress, 'value')) # This link enable auto refresh from outside
     
     return intprogress, html
 
 def _notification(content,title='IPySlides Notification',timeout=5):
-    _title = f'<b>{title}</b>' if title else '' # better for inslides notification
+    _title = f'<b>🔔 {title}</b><br/>' if title else '' # better for inslides notification
     return f'''<style>
         .NotePop {{
             display:flex;
             flex-direction:row;
-            background: linear-gradient(to right, var(--tr-hover-bg) 0%, var(--secondary-bg) 100%);
             border-radius: 4px;
             padding:8px;
-            opacity:0.9;
             width:auto;
             max-width:400px;
             height:max-content;
-            box-shadow: 0 0 2px 2px var(--tr-hover-bg);
+            backdrop-filter: blur(20px);
+            box-shadow: 0 0 5px 0 rgba(255,255,255,0.2), 0 0 10px 0 rgba(0,0,0,0.2);
             animation: popup 0s ease-in {timeout}s;
             animation-fill-mode: forwards;
         }}
-        .NotePop>div>b {{color: var(--accent-color);}}
+        .NotePop > div > b {{color: var(--accent-color); font-size:18px !important;}}
+        .NotePop.NotePop.NotePop.NotePop > div > p {{ border-left: 2px solid var(--accent-color);padding-left:4px;font-size:16px !important;}}
         @keyframes popup {{
             to {{
                 visibility:hidden;
@@ -195,12 +193,9 @@ def _notification(content,title='IPySlides Notification',timeout=5):
             }}
         }}
         </style>
-        <div style="position:absolute;left:8px;top:8px;z-index:1000;" class="NotePop">
-        <div style="width:4px;background: var(--accent-color);margin-left:-8px;margin-right:8px"></div>
+        <div style="position:absolute;left:50%;top:4px;z-index:1000;transform:translateX(-50%);" class="NotePop">
         <div>{_title}<p>{content}</p></div></div>'''
 
-    
-    
 class Widgets:
     """
     Instantiate under `LiveSLides` class only and provide to other classes after built-up.
@@ -217,7 +212,7 @@ class Widgets:
     @property
     def assets_dir(self):
         "Returns the assets directory, if not exist, create one"
-        _dir = os.path.join(self._notebook_dir,'ipyslides-assets')
+        _dir = os.path.join(self._notebook_dir,'.ipyslides_assets')
         if not os.path.isdir(_dir):
             os.makedirs(_dir)
         return _dir
@@ -235,7 +230,7 @@ class Widgets:
         self.outputs = _Outputs()
         
         # Make the progress bar and link to slides
-        self.progressbar, self.__proghtml = _custom_progressbar(self.sliders.progress)
+        self.progressbar, self._proghtml = _custom_progressbar(self.sliders.progress)
         
         # Layouts build on these widgets
         self.controls = HBox([
@@ -244,36 +239,33 @@ class Widgets:
                 self.sliders.progress 
             ]).add_class('ProgBox') ,
             self.buttons.next
-        ]).add_class('controls') 
+        ]).add_class('Controls') 
         
         self.footerbox = HBox([
-            self.buttons.setting,
             self.buttons.toc,
-            HBox([self.htmls.footer],layout= Layout(overflow_x = 'auto',overflow_y='hidden')),
+            HBox([self.htmls.footer]), # should be in Box to avoid overflow
             self.buttons.capture,
-        ],layout=Layout(height='36px')).add_class('nav-box')
+        ],layout=Layout(height='28px')).add_class('NavBox')
         
         self.navbox = VBox([
             self.footerbox,
             VBox([
-                self.__proghtml,
+                self._proghtml,
                 self.progressbar
                 ])
         ]).add_class('NavWrapper')   #class is must
         
+        _many_btns = [self.buttons.setting, self.toggles.overlay, self.toggles.window, self.toggles.fscreen, self.toggles.laser, self.toggles.zoom, self.buttons.refresh]
         self.panelbox = VBox([
             self.htmls.glass,
-            self.buttons.setting,
+            HBox(_many_btns).add_class('TopBar').add_class('Inside'),
             VBox([
-                self.sliders.height.add_class('voila-sidecar-hidden'), 
-                self.sliders.width.add_class('voila-sidecar-hidden'),
+                self.sliders.width,
+                self.ddowns.aspect, 
                 self.sliders.scale,
                 self.ddowns.theme,
-                self.toggles.export,
+                self.ddowns.export,
                 Box([GridBox([
-                    self.toggles.fscrn,
-                     self.toggles.zoom,
-                    self.toggles.timer,
                     self.checks.notes,
                     self.checks.toast,
                     self.checks.reflow,
@@ -292,7 +284,7 @@ class Widgets:
                 self.outputs.slide,
                 self.htmls.intro  
             ],layout=Layout(width='auto',height='auto',overflow_y='scroll',padding='8px',margin='0'))
-        ],layout = Layout(width='70%',min_width='50%',height='100%',overflow='hidden',display='none')).add_class('panel') 
+        ],layout = Layout(width='70%',min_width='50%',height='100%',overflow='hidden',display='none')).add_class('SidePanel') 
         
         self.tocbox = VBox([],layout = Layout(width='30%',min_width='400px',height='100%',overflow='auto',display='none')).add_class('TOC')
         
@@ -301,27 +293,27 @@ class Widgets:
         ],layout= Layout(min_width='100%',overflow='auto')).add_class('SlideBox') 
         
         self.mainbox = VBox([
-            self.htmls.glass, # This is the glass pane, should be on top of everything
+            self.htmls.glass, # This is the glass pane, should be before everything, otherwise it will cover the slide area
             self.htmls.loading, 
             self.htmls.toast,
             self.htmls.main,
             self.htmls.theme,
             self.htmls.logo,
-            self.toggles.display,
-            self.htmls.sidebar,
+            HBox(_many_btns).add_class('TopBar').add_class('Outside'),
+            self.htmls.window,
             self.panelbox,
             self.htmls.cursor,
             self.htmls.hilite,
             self.htmls.zoom,
-            self.htmls.fscrn,
             HBox([ #Slide_box must be in a box to have animations work
                 self.tocbox, # Should be on left of slides
                 self.slidebox , 
             ],layout= Layout(width='100%',max_width='100%',height='100%',overflow='hidden')), #should be hidden for animation purpose
             self.controls, # Importnat for unique display
             self.sliders.visible,
-            self.navbox
-            ],layout= Layout(width=f'{self.sliders.width.value}vw', height=f'{self.sliders.height.value}px',margin='auto')
+            self.htmls.overlay, 
+            self.navbox, # Navbox should come last
+            ],layout= Layout(width=f'{self.sliders.width.value}vw', height=f'{int(self.sliders.width.value*self.ddowns.aspect.value)}vw',margin='auto')
         ).add_class('SlidesWrapper')  #Very Important to add this class
 
         for btn in [self.buttons.next, self.buttons.prev, self.buttons.setting,self.buttons.capture]:
@@ -334,9 +326,10 @@ class Widgets:
         if content and isinstance(content,str):
             self.htmls.toast.value = '' # Set first to '', otherwise may not trigger for same value again.
             self.htmls.toast.value = _notification(content=content,title=title,timeout=timeout)
-    
+        
     def _exec_js(self,code_string):
         "Execute javascript code, output is not permanent."
         self.outputs.renew.clear_output(wait = True)
         with self.outputs.renew:
-            display(Javascript(code_string))
\ No newline at end of file
+            display(Javascript(code_string))
+            
\ No newline at end of file
